import { ContactMsg, ContactAddMsg, ChatroomMsg } from './messages';
import { Client } from 'ts-linker-sdk';
export interface WebSocketClientStatus {
    created: boolean;
    connected: boolean;
    login: boolean;
}
export interface WebSocketResp {
    value: object | string;
}
export declare type ListenerCallback = (data: WebSocketResp) => void;
export declare class WebSocketClient {
    client: Client;
    interval: number;
    wsUrl: string;
    token: string;
    sid: string;
    chatToken: object;
    status: WebSocketClientStatus;
    constructor(wsUrl: string, token: string, sid: string, chatToken: object);
    init(): Promise<{}>;
    getStatus(): WebSocketClientStatus;
    create(): Promise<{}>;
    on(url: string, callback: (data: WebSocketResp) => void): void;
    off(url: string): void;
    request(url: string, data: object): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    connect(): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    ping(): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    authentication(): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    onMessage(callback: ListenerCallback): Promise<void>;
    sendMessage(data: object): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    markServiced(data: {
        msg_id: string;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    getHistoryMessage(data: {
        contact_id: string;
        chat_type: string;
        start_time: number;
        limit: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    updateStatus(data: {
        status: 'on' | 'off' | 'busy';
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    getSessionLists(): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    getAllConversations(data: {
        last_pull: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    getAllContact(data: {
        last_pull: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    addContact(data: {
        to_add_username: string;
        reason: string;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    deleteContact(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    maskingContact(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeMaskingContact(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    stickingContact(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeStickContact(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    setNoDisturbing(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeNoDisturbing(data: ContactMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    agreeAddContact(data: ContactAddMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    rejectAddContact(data: ContactAddMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    addContactServiced(data: ContactAddMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    createChatroom(data: {
        subject: string;
        description: string;
        welcome_message: string;
        max: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    destroyChatroom(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    leaveChatroom(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    getChatroomProfile(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    updateChatroomSubject(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    updateChatroomDescription(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    addChatroomAdmin(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeChatroomAdmin(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    addChatroomAdmins(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeChatroomAdmins(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    joinChatroom(data: {}): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    removeChatroomMember(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    fetchStickChatroom(data: {
        cache_time: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    fetchChatroomMembers(data: ChatroomMsg): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
    searchHistoryMessage(data: {
        contact_id: string;
        chat_type: string;
        keyword: string;
        limit: number;
    }): Promise<import("ts-linker-sdk/dist/types/types").WebSocketResp>;
}
